@@ -108,7 +108,9 @@ CB_new_steal_from_trusted_str(char *ptr, size_t size, size_t cap) {
 
 CharBuf*
 CB_new_steal_str(char *ptr, size_t size, size_t cap) {
-    StrHelp_utf8_valid(ptr, size);
+    if (!StrHelp_utf8_valid(ptr, size)) {
+        DIE_INVALID_UTF8(ptr, size);
+    }
     return CB_new_steal_from_trusted_str(ptr, size, cap);
 }
 
@@ -133,13 +135,11 @@ CB_hash_sum(CharBuf *self) {
     uint32_t hashvalue = 5381;
     ZombieCharBuf *iterator = ZCB_WRAP(self);
 
-    {
-        const CB_nip_one_t nip_one
-            = (CB_nip_one_t)METHOD(iterator->vtable, CB, Nip_One);
-        while (iterator->size) {
-            uint32_t code_point = (uint32_t)nip_one((CharBuf*)iterator);
-            hashvalue = ((hashvalue << 5) + hashvalue) ^ code_point;
-        }
+    const CB_nip_one_t nip_one
+        = (CB_nip_one_t)METHOD(iterator->vtable, CB, Nip_One);
+    while (iterator->size) {
+        uint32_t code_point = (uint32_t)nip_one((CharBuf*)iterator);
+        hashvalue = ((hashvalue << 5) + hashvalue) ^ code_point;
     }
 
     return (int32_t) hashvalue;
@@ -618,6 +618,9 @@ CB_trim_top(CharBuf *self) {
         ptr += StrHelp_UTF8_COUNT[*(uint8_t*)ptr];
         count++;
     }
+    if (ptr > end) {
+        DIE_INVALID_UTF8(self->ptr, self->size);
+    }
 
     if (count) {
         // Copy string backwards.
@@ -654,6 +657,9 @@ CB_nip(CharBuf *self, size_t count) {
     for (; ptr < end  && count--; ptr += StrHelp_UTF8_COUNT[*(uint8_t*)ptr]) {
         num_nipped++;
     }
+    if (ptr > end) {
+        DIE_INVALID_UTF8(self->ptr, self->size);
+    }
     self->size = end - ptr;
     memmove(self->ptr, ptr, self->size);
     return num_nipped;
@@ -667,6 +673,9 @@ CB_nip_one(CharBuf *self) {
     else {
         int32_t retval = (int32_t)StrHelp_decode_utf8_char(self->ptr);
         size_t consumed = StrHelp_UTF8_COUNT[*(uint8_t*)self->ptr];
+        if (consumed > self->size) {
+            DIE_INVALID_UTF8(self->ptr, self->size);
+        }
         char *ptr = self->ptr + StrHelp_UTF8_COUNT[*(uint8_t*)self->ptr];
         self->size -= consumed;
         memmove(self->ptr, ptr, self->size);
@@ -696,6 +705,9 @@ CB_length(CharBuf *self) {
         ptr += StrHelp_UTF8_COUNT[*(uint8_t*)ptr];
         len++;
     }
+    if (ptr != end) {
+        DIE_INVALID_UTF8(self->ptr, self->size);
+    }
     return len;
 }
 
@@ -715,7 +727,12 @@ CB_code_point_at(CharBuf *self, size_t tick) {
     char *const end = ptr + self->size;
 
     for (; ptr < end; ptr += StrHelp_UTF8_COUNT[*(uint8_t*)ptr]) {
-        if (count == tick) { return StrHelp_decode_utf8_char(ptr); }
+        if (count == tick) {
+            if (ptr > end) {
+                DIE_INVALID_UTF8(self->ptr, self->size);
+            }
+            return StrHelp_decode_utf8_char(ptr);
+        }
         count++;
     }
 
@@ -852,6 +869,9 @@ ViewCB_trim_top(ViewCharBuf *self) {
     }
 
     if (count) {
+        if (ptr > end) {
+            DIE_INVALID_UTF8(self->ptr, self->size);
+        }
         self->size = end - ptr;
         self->ptr  = ptr;
     }
@@ -870,6 +890,9 @@ ViewCB_nip(ViewCharBuf *self, size_t count) {
         ) {
         num_nipped++;
     }
+    if (ptr > end) {
+        DIE_INVALID_UTF8(self->ptr, self->size);
+    }
     self->size = end - ptr;
     self->ptr  = ptr;
     return num_nipped;
@@ -883,6 +906,9 @@ ViewCB_nip_one(ViewCharBuf *self) {
     else {
         int32_t retval = (int32_t)StrHelp_decode_utf8_char(self->ptr);
         size_t consumed = StrHelp_UTF8_COUNT[*(uint8_t*)self->ptr];
+        if (consumed > self->size) {
+            DIE_INVALID_UTF8(self->ptr, self->size);
+        }
         self->ptr  += consumed;
         self->size -= consumed;
         return retval;
