@@ -80,12 +80,12 @@ say qq|perl -MDigest -e '\$d = Digest->new("MD5"); open \$fh, |
     . qq|"<apache-lucy-incubating-$x_y_z_version.tar.gz" or die; |
     . qq|\$d->addfile(\$fh); print \$d->hexdigest; |
     . qq|print "  apache-lucy-incubating-$x_y_z_version.tar.gz\\n"' > |
-    . qq| apache-lucy-incubating-0.2.2.tar.gz.md5|;
+    . qq| apache-lucy-incubating-$x_y_z_version.tar.gz.md5|;
 say qq|perl -MDigest -e '\$d = Digest->new("SHA-512"); open \$fh, |
     . qq|"<apache-lucy-incubating-$x_y_z_version.tar.gz" or die; |
     . qq|\$d->addfile(\$fh); print \$d->hexdigest; |
     . qq|print "  apache-lucy-incubating-$x_y_z_version.tar.gz\\n"' > |
-    . qq| apache-lucy-incubating-0.2.2.tar.gz.sha\n|;
+    . qq| apache-lucy-incubating-$x_y_z_version.tar.gz.sha\n|;
 
 say qq|# Sign the release.|;
 say qq|gpg --armor --output apache-lucy-incubating-$x_y_z_version.tar.gz.asc |
@@ -236,6 +236,8 @@ information on ASF voting procedures, see:
 [ ] +0
 [ ] -1 Do not release RC $rc as Apache Lucy (incubating) version $x_y_z_version because...
 
+Here's my +1.
+
 Thanks!
 END_LUCY_DEV_VOTE
 
@@ -308,9 +310,9 @@ Greetings,
 The Apache Lucy team is pleased to announce the release of version $x_y_z_version
 from the Apache Incubator!
 
-Apache Lucy is full-text search engine library written in C and targeted at
-dynamic languages.  For a list of issues resolved in this version, please see
-the release notes:
+The Apache Lucy search engine library provides full-text search for dynamic
+programming languages.  For a list of issues resolved in this version, please
+see the release notes:
 
   http://www.apache.org/dist/incubator/lucy/CHANGES-$x_y_z_version.txt
 
