@@ -34,7 +34,7 @@ my $constructor = <<'END_CONSTRUCTOR';
     my $case_folder = Lucy::Analysis::CaseFolder->new;
 END_CONSTRUCTOR
 
-Clownfish::Binding::Perl::Class->register(
+Clownfish::CFC::Binding::Perl::Class->register(
     parcel            => "Lucy",
     class_name        => "Lucy::Analysis::CaseFolder",
     bind_constructors => ["new"],
