@@ -21,7 +21,7 @@ __END__
 
 __BINDING__
 
-Clownfish::Binding::Perl::Class->register(
+Clownfish::CFC::Binding::Perl::Class->register(
     parcel     => "Lucy",
     class_name => "Lucy::Docs::DevGuide",
     make_pod   => {},
