@@ -38,7 +38,7 @@ my $synopsis = <<'END_SYNOPSIS';
     }
 END_SYNOPSIS
 
-Clownfish::Binding::Perl::Class->register(
+Clownfish::CFC::Binding::Perl::Class->register(
     parcel     => "Lucy",
     class_name => "Lucy::Store::LockErr",
     make_pod   => { synopsis => $synopsis }
