@@ -32,7 +32,7 @@ CODE:
 OUTPUT: RETVAL
 END_XS_CODE
 
-Clownfish::Binding::Perl::Class->register(
+Clownfish::CFC::Binding::Perl::Class->register(
     parcel       => "Lucy",
     class_name   => "Lucy::Util::SortExternal",
     xs_code      => $xs_code,
