@@ -192,7 +192,7 @@ __END__
 
 __BINDING__
 
-Clownfish::Binding::Perl::Class->register(
+Clownfish::CFC::Binding::Perl::Class->register(
     parcel            => "Lucy",
     class_name        => "LucyX::Search::FilterMatcher",
     bind_constructors => ["new"],
